@@ -1,7 +1,7 @@
 // padthv1widget_config.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
 // forward decls.
 namespace Ui { class padthv1widget_config; }
 
+class padthv1widget;
 class padthv1_ui;
 
 class QComboBox;
@@ -46,7 +47,7 @@ class padthv1widget_config : public QDialog
 public:
 
 	// ctor.
-	padthv1widget_config(padthv1_ui *pSynthUi, QWidget *pParent = nullptr);
+	padthv1widget_config(padthv1widget *pParent, padthv1_ui *pSynthUi);
 
 	// dtor.
 	~padthv1widget_config();
@@ -107,6 +108,9 @@ protected:
 	bool setComboBoxCurrentItem(QComboBox *pComboBox, const QFileInfo& info);
 	QString comboBoxCurrentItem(QComboBox *pComboBox);
 
+	// Programs/preset preview stuff...
+	void loadPreset(const QString& sPreset);
+
 	// stabilizer.
 	void stabilize();
 
@@ -124,6 +128,12 @@ private:
 	int m_iDirtyControls;
 	int m_iDirtyPrograms;
 	int m_iDirtyOptions;
+
+	// Programs/preset related stuff...
+	bool    m_bPresets;
+
+	int		m_iLoadPreset;
+	QString m_sSavePreset;
 };
 
 
